@@ -197,7 +197,7 @@ parsing resulting JSON output and returning a Julia dictionary of the contents.
 "Run conda command with environment variables set and return the json output as a julia object"
 function parseconda(args::Cmd, env::Environment=ROOTENV)
     _install_conda(env)
-    JSON.parse(read(_set_conda_env(`$conda $args --json`, env), String))
+    JSON.parse(read(_set_conda_env(`$conda $args --json`, env), String); dicttype=Dict{String, Any})
 end
 
 """
